@@ -26,9 +26,9 @@ make.par.list <- function(nams, x, n, m, def, recycle = sum(unnamed) > 0) {
   y[in.x] <- x[nams[in.x]]
   if (recycle) {
     stopifnot(sum(unnamed) > 0)
-    y[!in.x] <- x[unnamed]
+    y[!in.x] <- rep(x[unnamed], length.out = sum(!in.x)) ## CHECK, this was: x[unnamed]
   } else {
-    y[which(!in.x)[seq(len=sum(unnamed))]] <- x[unnamed]
+    y[which(!in.x)[seq_len(sum(unnamed))]] <- x[unnamed]
   }
   lapply(y, function(y) if (length(y)==1) y else rep(y, length.out = n))
 }
@@ -37,7 +37,8 @@ plot.zoo <- function(x, y = NULL, screens, plot.type, panel = lines,
   xlab = "Index", ylab = NULL, main = NULL, xlim = NULL, ylim = NULL,
   xy.labels = FALSE, xy.lines = NULL,
   oma = c(6, 0, 5, 0), mar = c(0, 5.1, 0, 2.1), 
-  col = 1, lty = 1, pch = 1, type = "l", nc, widths = 1, heights = 1, ...)
+  col = 1, lty = 1, lwd = 1, pch = 1, type = "l", 
+  nc, widths = 1, heights = 1, ...)
 {
   ## if y supplied: scatter plot y ~ x
   if(!is.null(y)) {
@@ -59,7 +60,7 @@ plot.zoo <- function(x, y = NULL, screens, plot.type, panel = lines,
       xlab = xlab, ylab = ylab, xlim = xlim, ylim = ylim, ...)
     if(do.lab) text(xy, col = col,
       labels = if(!is.logical(xy.labels)) xy.labels else index2char(index(xyzoo)), ...)
-    if(xy.lines) lines(xy, col = col, lty = lty, type = if(do.lab) "c" else "l", ...)
+    if(xy.lines) lines(xy, col = col, lty = lty, lwd = lwd, type = if(do.lab) "c" else "l", ...)
 
     return(invisible(xyzoo))
   }
@@ -82,7 +83,7 @@ plot.zoo <- function(x, y = NULL, screens, plot.type, panel = lines,
   dots <- list(...)
   x.index <- index(x)
   if(is.ts(x.index)) x.index <- as.vector(x.index)
-  cn <- if (is.null(colnames(x))) paste("V", seq(length = nser), sep = "")
+  cn <- if (is.null(colnames(x))) paste("V", seq_len(nser), sep = "")
 	  else colnames(x)
 
   screens <- make.par.list(cn, screens, NROW(x), nser, 1)
@@ -99,6 +100,7 @@ plot.zoo <- function(x, y = NULL, screens, plot.type, panel = lines,
     if(is.null(ylab)) ylab <- paste("Series", which(!duplicated(screens)))
     ylab <- rep(ylab, length.out = ngraph)
     lty <- rep(lty, length.out = nser)
+    lwd <- rep(lwd, length.out = nser)
     col <- make.par.list(cn, col, NROW(x), nser, 1)
     pch <- make.par.list(cn, pch, NROW(x), nser, par("pch"))
     type <- make.par.list(cn, type, NROW(x), nser, "l")
@@ -126,31 +128,32 @@ plot.zoo <- function(x, y = NULL, screens, plot.type, panel = lines,
 	# otherwise, if the ylim are specified use the range of the ylim values;
 	# otherwise, use the range of the data
 	f <- function(idx) if (allsame(ylim)) ylim[idx][[1]]
-		else if (!is.null(ylim) && length(idx) > 0) 
-			range(ylim[idx], finite = TRUE)
+		else if (!is.null(ylim) && length(idx) > 0 && 
+			length(unlist(ylim[idx])) > 0) range(ylim[idx], finite = TRUE)
 		else range(x[, idx], na.rm = TRUE)
 	# ranges is indexed by screen
 	ranges <- tapply(1:ncol(x), screens, f)
-    for(j in seq(along = levels(screens))) {
+    for(j in seq_along(levels(screens))) {
       panel.number <- j
       range. <- rep(ranges[[j]], length.out = length(time(x)))
       if(j%%nr==0 || j == length(levels(screens))) {
-	args <- list(x.index, range., xlab = "", ylab = ylab[j], 
-		xlim = xlim, ylim = ylim[[j]], ...)
-	args$type <- "n"
-	do.call("plot", args)
-	mtext(xlab, side = 1, line = 3)
+			args <- list(x.index, range., xlab = "", ylab = ylab[j], 
+				xlim = xlim, ylim = ylim[[j]], ...)
+			args$type <- "n"
+			do.call("plot", args)
+			mtext(xlab, side = 1, line = 3)
       } else {      
-        args <- list(x.index, range., axes = FALSE, xlab = "", ylab = ylab[j], 
-		xlim = xlim, ylim = ylim[[j]], ...)
-	args$type <- "n"
-	do.call("plot", args)
-        box()
-        axis(2, xpd = NA)
+			# args <- list(x.index, range., axes = FALSE, xlab = "", 
+			args <- list(x.index, range., xaxt = "n", xlab = "", 
+				ylab = ylab[j], xlim = xlim, ylim = ylim[[j]], ...)
+			args$type <- "n"
+			do.call("plot", args)
+			box()
+			# axis(2, xpd = NA)
       }
 
       for(i in which(screens == levels(screens)[j]))
-        panel(x.index, x[, i], col = col[[i]], pch = pch[[i]], lty = lty[i], type = type[[i]], ...)
+        panel(x.index, x[, i], col = col[[i]], pch = pch[[i]], lty = lty[i], lwd = lwd[i], type = type[[i]], ...)
     }
   } else {
     if(is.null(ylab)) ylab <- deparse(substitute(x))
@@ -160,6 +163,7 @@ plot.zoo <- function(x, y = NULL, screens, plot.type, panel = lines,
 	else ylim <- range2(c(ylim, recursive = TRUE), na.rm = TRUE)
 
     lty <- rep(lty, length.out = nser)
+	lwd <- rep(lwd, length.out = nser)
     col <- make.par.list(cn, col, NROW(x), nser, 1)
     pch <- make.par.list(cn, pch, NROW(x), nser, par("pch"))
     type <- make.par.list(cn, type, NROW(x), nser, "l")
@@ -174,7 +178,7 @@ plot.zoo <- function(x, y = NULL, screens, plot.type, panel = lines,
     y <- as.matrix(x)
     for(i in 1:nser) {
       panel(x.index, y[, i], col = col[[i]], pch = pch[[i]], lty = lty[i], 
-		type = type[[i]], ...)
+        lwd = lwd[i], type = type[[i]], ...)
     }
   }
   title(main, outer = main.outer)
@@ -193,3 +197,17 @@ lines.zoo <- function(x, y = NULL, type = "l", ...)
 points.zoo <- function(x, y = NULL, type = "p", ...)
   lines(x, y, type = type, ...)
 
+
+plot.tis <- function(x, ...) eval.parent(substitute(plot(as.zoo(x), ...)))
+
+plot.ti <- function (x, y, xlab = "", ...) 
+{
+	x <- POSIXct(x)
+	NextMethod()
+}
+
+points.ti <- lines.ti <- function(x, ...) {
+	x <- POSIXct(x)
+	NextMethod()
+}
+
